==> ejc-bfyjerp-impl-3.0.0-20250408.025344-183-sources.jar: com/ejianc/business/oa/bean/CertSalaryDetailEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-证书人员工资表子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_cert_salary_detail")
public class CertSalaryDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="cert_salary_id")
    private Long certSalaryId; // 证书人员工资主表id
    @TableField(value="cert_salary_month")
    private Date certSalaryMonth; // 主表月份
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="human_type")
    private Integer humanType; // 人员类别
    @TableField(value="human_type_name")
    private String humanTypeName; // 人员类别名称
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 应发工资
    @TableField(value="other_pay_mny")
    private BigDecimal otherPayMny; // 其他应付款
    @TableField(value="other_deduct_mny")
    private BigDecimal otherDeductMny; // 其他扣款
    @TableField(value="actual_salary_mny")
    private BigDecimal actualSalaryMny; // 实发工资
    @TableField(value="in_date")
    private Date inDate; // 迁入日期
    @TableField(value="end_Date")
    private Date endDate; // 结束日期
    @TableField(value="cert")
    private String cert; // 证书明细
    @TableField(value="cert_name")
    private String certName; // 证书明细
    @TableField(value="source_id")
    private Long sourceId; // 来源id即证书人员id
    @TableField(value="cert_mny")
    private BigDecimal certMny; // 证书费用


    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }

    public Long getCertSalaryId() {
        return certSalaryId;
    }

    public void setCertSalaryId(Long certSalaryId) {
        this.certSalaryId = certSalaryId;
    }
    public Date getCertSalaryMonth() {
        return certSalaryMonth;
    }

    public void setCertSalaryMonth(Date certSalaryMonth) {
        this.certSalaryMonth = certSalaryMonth;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }
    public Date getInDate() {
        return inDate;
    }

    public void setInDate(Date inDate) {
        this.inDate = inDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public String getCert() {
        return cert;
    }

    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250410.073655-192-sources.jar: com/ejianc/business/oa/bean/CertSalaryDetailEntity.java <==
package com.ejianc.business.oa.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 人力行政-证书人员工资表子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_oa_cert_salary_detail")
public class CertSalaryDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="cert_salary_id")
    private Long certSalaryId; // 证书人员工资主表id
    @TableField(value="cert_salary_month")
    private Date certSalaryMonth; // 主表月份
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="human_type")
    private Integer humanType; // 人员类别
    @TableField(value="human_type_name")
    private String humanTypeName; // 人员类别名称
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 应发工资
    @TableField(value="other_pay_mny")
    private BigDecimal otherPayMny; // 其他应付款
    @TableField(value="other_deduct_mny")
    private BigDecimal otherDeductMny; // 其他扣款
    @TableField(value="actual_salary_mny")
    private BigDecimal actualSalaryMny; // 实发工资
    @TableField(value="in_date")
    private Date inDate; // 迁入日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="cert")
    private String cert; // 证书明细
    @TableField(value="cert_name")
    private String certName; // 证书明细
    @TableField(value="source_id")
    private Long sourceId; // 来源id即证书人员id
    @TableField(value="cert_mny")
    private BigDecimal certMny; // 证书费用
    @TableField(value="pay_type")
    private Integer payType; // 付款方式
    @TableField(value="pay_type_name")
    private String payTypeName; // 付款方式

    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }

    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }

    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }

    public Long getCertSalaryId() {
        return certSalaryId;
    }

    public void setCertSalaryId(Long certSalaryId) {
        this.certSalaryId = certSalaryId;
    }
    public Date getCertSalaryMonth() {
        return certSalaryMonth;
    }

    public void setCertSalaryMonth(Date certSalaryMonth) {
        this.certSalaryMonth = certSalaryMonth;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }
    public Date getInDate() {
        return inDate;
    }

    public void setInDate(Date inDate) {
        this.inDate = inDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public String getCert() {
        return cert;
    }

    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}
